==> calligra_2.8.1-1.orig.tar.xz: calligra-2.8.1/libs/flake/KoCanvasObserverBase.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2007 Thomas Zander <zander@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "KoCanvasObserverBase.h"

class KoCanvasObserverBasePrivate
{
public:
    KoCanvasObserverBasePrivate()
        : canvas(0)
    {}

    ~KoCanvasObserverBasePrivate()
    {}

    KoCanvasBase* canvas;
};

KoCanvasObserverBase::KoCanvasObserverBase()
    : d(new KoCanvasObserverBasePrivate)
{
}

KoCanvasObserverBase::~KoCanvasObserverBase()
{
    delete d;
}

void KoCanvasObserverBase::setObservedCanvas(KoCanvasBase* canvas)
{
    d->canvas = canvas;
    setCanvas(canvas);
}

void KoCanvasObserverBase::unsetObservedCanvas()
{
    d->canvas = 0;
    unsetCanvas();
}

KoCanvasBase* KoCanvasObserverBase::observedCanvas()
{
    return d->canvas;
}

==> calligra_3.1.0+dfsg.orig.tar.xz: calligra-3.1.0/libs/flake/KoCanvasObserverBase.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2007 Thomas Zander <zander@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "KoCanvasObserverBase.h"

#include <QString>


class KoCanvasObserverBasePrivate
{
public:
    KoCanvasObserverBasePrivate()
        : canvas(0)
    {}

    ~KoCanvasObserverBasePrivate()
    {}

    KoCanvasBase* canvas;
};

KoCanvasObserverBase::KoCanvasObserverBase()
    : d(new KoCanvasObserverBasePrivate)
{
}

KoCanvasObserverBase::~KoCanvasObserverBase()
{
    delete d;
}

QString KoCanvasObserverBase::observerName() const
{
    return QString();
}

void KoCanvasObserverBase::setObservedCanvas(KoCanvasBase* canvas)
{
    d->canvas = canvas;
    setCanvas(canvas);
}

void KoCanvasObserverBase::unsetObservedCanvas()
{
    d->canvas = 0;
    unsetCanvas();
}

KoCanvasBase* KoCanvasObserverBase::observedCanvas() const
{
    return d->canvas;
}
